@@ -40,7 +40,7 @@ in this Software without prior written authorization from The Open Group.
 
 static XExtensionInfo _shm_info_data;
 static XExtensionInfo *shm_info = &_shm_info_data;
-static /* const */ char *shm_extension_name = SHMNAME;
+static const char *shm_extension_name = SHMNAME;
 
 #define ShmCheckExtension(dpy,i,val) \
   XextCheckExtension (dpy, i, shm_extension_name, val)
@@ -70,11 +70,11 @@ static /* const */ XExtensionHooks shm_extension_hooks = {
     error_string,			/* error_string */
 };
 
-static /* const */ char *shm_error_list[] = {
+static const char *shm_error_list[] = {
     "BadShmSeg",			/* BadShmSeg */
 };
 
-static XEXT_GENERATE_FIND_DISPLAY (find_display, shm_info, shm_extension_name, 
+static XEXT_GENERATE_FIND_DISPLAY (find_display, shm_info, shm_extension_name,
 				   &shm_extension_hooks, ShmNumberEvents, NULL)
 
 static XEXT_GENERATE_CLOSE_DISPLAY (close_display, shm_info)
@@ -223,7 +223,7 @@ int XShmPixmapFormat(Display *dpy)
 }
 
 
-Status XShmAttach(Display *dpy, XShmSegmentInfo *shminfo)
+Bool XShmAttach(Display *dpy, XShmSegmentInfo *shminfo)
 {
     XExtDisplayInfo *info = find_display (dpy);
     register xShmAttachReq *req;
@@ -243,7 +243,7 @@ Status XShmAttach(Display *dpy, XShmSegmentInfo *shminfo)
 }
 
 
-Status XShmDetach(Display *dpy, XShmSegmentInfo *shminfo)
+Bool XShmDetach(Display *dpy, XShmSegmentInfo *shminfo)
 {
     XExtDisplayInfo *info = find_display (dpy);
     register xShmDetachReq *req;
@@ -262,7 +262,7 @@ Status XShmDetach(Display *dpy, XShmSegmentInfo *shminfo)
 
 static int _XShmDestroyImage (XImage *ximage)
 {
-	Xfree((char *)ximage);
+	Xfree(ximage);
 	return 1;
 }
 
@@ -280,7 +280,7 @@ XImage *XShmCreateImage (
 {
     register XImage *image;
 
-    image = (XImage *)Xcalloc(1, (unsigned)sizeof(XImage));
+    image = Xcalloc(1, sizeof(XImage));
     if (!image)
 	return image;
     image->data = data;
@@ -312,7 +312,7 @@ XImage *XShmCreateImage (
     return image;
 }
 
-Status XShmPutImage (
+Bool XShmPutImage (
     register Display *dpy,
     Drawable d,
     GC gc,
@@ -354,7 +354,7 @@ Status XShmPutImage (
 }
 
 
-Status XShmGetImage(
+Bool XShmGetImage(
     register Display *dpy,
     Drawable d,
     XImage *image,
